@@ -2,89 +2,72 @@ from flask import current_app
 
 from alerta.exceptions import ApiError, InvalidAction
 from alerta.models.alarms import AlarmModel
+from alerta.models.enums import Action, Severity, Status, TrendIndication
 
 SEVERITY_MAP = {
-    'security': 0,
-    'critical': 1,
-    'major': 2,
-    'minor': 3,
-    'warning': 4,
-    'indeterminate': 5,
-    'informational': 6,
-    'normal': 7,
-    'ok': 7,
-    'cleared': 7,
-    'debug': 8,
-    'trace': 9,
-    'unknown': 10
+    Severity.Security: 0,
+    Severity.Critical: 1,
+    Severity.Major: 2,
+    Severity.Minor: 3,
+    Severity.Warning: 4,
+    Severity.Indeterminate: 5,
+    Severity.Informational: 6,
+    Severity.Normal: 7,
+    Severity.Ok: 7,
+    Severity.Cleared: 7,
+    Severity.Debug: 8,
+    Severity.Trace: 9,
+    Severity.Unknown: 10
 }
-DEFAULT_NORMAL_SEVERITY = 'normal'  # 'normal', 'ok', 'cleared'
-DEFAULT_PREVIOUS_SEVERITY = 'indeterminate'
+DEFAULT_NORMAL_SEVERITY = Severity.Normal  # 'normal', 'ok', 'cleared'
+DEFAULT_PREVIOUS_SEVERITY = Severity.Indeterminate
+
 
 COLOR_MAP = {
     'severity': {
-        'security': 'blue',
-        'critical': 'red',
-        'major': 'orange',
-        'minor': 'yellow',
-        'warning': 'dodgerblue',
-        'indeterminate': 'lightblue',
-        'cleared': '#00CC00',  # lime green
-        'normal': '#00CC00',
-        'ok': '#00CC00',
-        'informational': '#00CC00',
-        'debug': '#9D006D',  # purple
-        'trace': '#7554BF',  # violet
-        'unknown': 'silver'
+        Severity.Security: 'blue',
+        Severity.Critical: 'red',
+        Severity.Major: 'orange',
+        Severity.Minor: 'yellow',
+        Severity.Warning: 'dodgerblue',
+        Severity.Indeterminate: 'lightblue',
+        Severity.Cleared: '#00CC00',  # lime green
+        Severity.Normal: '#00CC00',
+        Severity.Ok: '#00CC00',
+        Severity.Informational: '#00CC00',
+        Severity.Debug: '#9D006D',  # purple
+        Severity.Trace: '#7554BF',  # violet
+        Severity.Unknown: 'silver'
+    },
+    'status': {
+        Status.Ack: 'skyblue',
+        Status.Shelved: 'skyblue'
     },
     'text': 'black'
 }
 
-OPEN = 'open'
-ASSIGN = 'assign'
-ACK = 'ack'
-SHELVED = 'shelved'
-BLACKOUT = 'blackout'
-CLOSED = 'closed'
-EXPIRED = 'expired'
-UNKNOWN = 'unknown'
-NOT_VALID = 'notValid'
-
 STATUS_MAP = {
-    OPEN: 'A',
-    ASSIGN: 'B',
-    ACK: 'C',
-    SHELVED: 'D',
-    BLACKOUT: 'E',
-    CLOSED: 'F',
-    EXPIRED: 'G',
-    UNKNOWN: 'H'
+    Status.Open: 'A',
+    Status.Assign: 'B',
+    Status.Ack: 'C',
+    Status.Shelved: 'D',
+    Status.Blackout: 'E',
+    Status.Closed: 'F',
+    Status.Expired: 'G',
+    Status.Unknown: 'H'
 }
 
-MORE_SEVERE = 'moreSevere'
-NO_CHANGE = 'noChange'
-LESS_SEVERE = 'lessSevere'
-
-ACTION_OPEN = 'open'
-ACTION_ASSIGN = 'assign'
-ACTION_ACK = 'ack'
-ACTION_UNACK = 'unack'
-ACTION_SHELVE = 'shelve'
-ACTION_UNSHELVE = 'unshelve'
-ACTION_CLOSE = 'close'
-ACTION_EXPIRED = 'expired'
-ACTION_TIMEOUT = 'timeout'
 
 ACTION_ALL = [
-    ACTION_OPEN,
-    ACTION_ASSIGN,
-    ACTION_ACK,
-    ACTION_UNACK,
-    ACTION_SHELVE,
-    ACTION_UNSHELVE,
-    ACTION_CLOSE,
-    ACTION_EXPIRED,
-    ACTION_TIMEOUT
+    Action.OPEN,
+    Action.ASSIGN,
+    Action.ACK,
+    Action.UNACK,
+    Action.SHELVE,
+    Action.UNSHELVE,
+    Action.CLOSE,
+    Action.EXPIRED,
+    Action.TIMEOUT
 ]
 
 
@@ -102,7 +85,7 @@ class StateMachine(AlarmModel):
         StateMachine.Colors = app.config['COLOR_MAP'] or COLOR_MAP
         StateMachine.Status = STATUS_MAP
 
-        StateMachine.DEFAULT_STATUS = OPEN
+        StateMachine.DEFAULT_STATUS = Status.Open
         StateMachine.DEFAULT_NORMAL_SEVERITY = app.config['DEFAULT_NORMAL_SEVERITY'] or DEFAULT_NORMAL_SEVERITY
         StateMachine.DEFAULT_PREVIOUS_SEVERITY = app.config['DEFAULT_PREVIOUS_SEVERITY'] or DEFAULT_PREVIOUS_SEVERITY
 
@@ -117,14 +100,14 @@ class StateMachine(AlarmModel):
 
     def trend(self, previous, current):
         if previous not in StateMachine.Severity or current not in StateMachine.Severity:
-            return NO_CHANGE
+            return TrendIndication.No_Change
 
         if StateMachine.Severity[previous] > StateMachine.Severity[current]:
-            return MORE_SEVERE
+            return TrendIndication.More_Severe
         elif StateMachine.Severity[previous] < StateMachine.Severity[current]:
-            return LESS_SEVERE
+            return TrendIndication.Less_Severe
         else:
-            return NO_CHANGE
+            return TrendIndication.No_Change
 
     def transition(self, alert, current_status=None, previous_status=None, action=None, **kwargs):
         current_status = current_status or StateMachine.DEFAULT_STATUS
@@ -164,107 +147,110 @@ class StateMachine(AlarmModel):
         # for auto-closing normal alerts, otherwise unchanged
         if not action and alert.status != StateMachine.DEFAULT_STATUS:
             if StateMachine.Severity[current_severity] == StateMachine.NORMAL_SEVERITY_LEVEL:
-                return next_state('SET-1', StateMachine.DEFAULT_NORMAL_SEVERITY, CLOSED)
+                return next_state('SET-1', StateMachine.DEFAULT_NORMAL_SEVERITY, Status.Closed)
             return next_state('SET-*', current_severity, alert.status)
 
         # state transition determined by operator action, if any, or severity changes
         state = current_status
 
-        if action == ACTION_UNACK:
-            if state == ACK:
+        if action == Action.UNACK:
+            if state == Status.Ack:
                 return next_state('UNACK-1', current_severity, previous_status)
             else:
                 raise InvalidAction('invalid action for current {} status'.format(state))
 
-        if action == ACTION_UNSHELVE:
-            if state == SHELVED:
+        if action == Action.UNSHELVE:
+            if state == Status.Shelved:
                 # as per ISA 18.2 recommendation 11.7.3 manually unshelved alarms transition to previous status
                 return next_state('UNSHL-1', current_severity, previous_status)
             else:
                 raise InvalidAction('invalid action for current {} status'.format(state))
 
-        if action == ACTION_EXPIRED:
-            return next_state('EXP-0', current_severity, EXPIRED)
+        if action == Action.EXPIRED:
+            return next_state('EXP-0', current_severity, Status.Expired)
 
-        if action == ACTION_TIMEOUT:
-            return next_state('OPEN-0', current_severity, OPEN)
+        if action == Action.TIMEOUT:
+            if previous_status == Status.Ack:
+                return next_state('ACK-0', current_severity, Status.Ack)
+            else:
+                return next_state('OPEN-0', current_severity, Status.Open)
 
-        if state == OPEN:
-            if action == ACTION_OPEN:
+        if state == Status.Open:
+            if action == Action.OPEN:
                 raise InvalidAction('alert is already in {} status'.format(state))
-            if action == ACTION_ACK:
-                return next_state('OPEN-1', current_severity, ACK)
-            if action == ACTION_SHELVE:
-                return next_state('OPEN-2', current_severity, SHELVED)
-            if action == ACTION_CLOSE:
-                return next_state('OPEN-3', StateMachine.DEFAULT_NORMAL_SEVERITY, CLOSED)
+            if action == Action.ACK:
+                return next_state('OPEN-1', current_severity, Status.Ack)
+            if action == Action.SHELVE:
+                return next_state('OPEN-2', current_severity, Status.Shelved)
+            if action == Action.CLOSE:
+                return next_state('OPEN-3', StateMachine.DEFAULT_NORMAL_SEVERITY, Status.Closed)
 
-        if state == ASSIGN:
+        if state == Status.Assign:
             pass
 
-        if state == ACK:
-            if action == ACTION_OPEN:
-                return next_state('ACK-1', current_severity, OPEN)
-            if action == ACTION_ACK:
+        if state == Status.Ack:
+            if action == Action.OPEN:
+                return next_state('ACK-1', current_severity, Status.Open)
+            if action == Action.ACK:
                 raise InvalidAction('alert is already in {} status'.format(state))
-            if action == ACTION_SHELVE:
-                return next_state('ACK-2', current_severity, SHELVED)
-            if action == ACTION_CLOSE:
-                return next_state('ACK-3', StateMachine.DEFAULT_NORMAL_SEVERITY, CLOSED)
+            if action == Action.SHELVE:
+                return next_state('ACK-2', current_severity, Status.Shelved)
+            if action == Action.CLOSE:
+                return next_state('ACK-3', StateMachine.DEFAULT_NORMAL_SEVERITY, Status.Closed)
 
             # re-open ack'ed alerts if the severity actually increases
             # not just because the previous severity is the default
             if previous_severity != StateMachine.DEFAULT_PREVIOUS_SEVERITY:
-                if self.trend(previous_severity, current_severity) == MORE_SEVERE:
-                    return next_state('ACK-4', current_severity, OPEN)
+                if self.trend(previous_severity, current_severity) == TrendIndication.More_Severe:
+                    return next_state('ACK-4', current_severity, Status.Open)
 
-        if state == SHELVED:
-            if action == ACTION_OPEN:
-                return next_state('SHL-1', current_severity, OPEN)
-            if action == ACTION_ACK:
+        if state == Status.Shelved:
+            if action == Action.OPEN:
+                return next_state('SHL-1', current_severity, Status.Open)
+            if action == Action.ACK:
                 raise InvalidAction('invalid action for current {} status'.format(state))
-            if action == ACTION_SHELVE:
+            if action == Action.SHELVE:
                 raise InvalidAction('alert is already in {} status'.format(state))
-            if action == ACTION_CLOSE:
-                return next_state('SHL-2', StateMachine.DEFAULT_NORMAL_SEVERITY, CLOSED)
+            if action == Action.CLOSE:
+                return next_state('SHL-2', StateMachine.DEFAULT_NORMAL_SEVERITY, Status.Closed)
 
-        if state == BLACKOUT:
-            if action == ACTION_CLOSE:
-                return next_state('BLK-1', StateMachine.DEFAULT_NORMAL_SEVERITY, CLOSED)
+        if state == Status.Blackout:
+            if action == Action.CLOSE:
+                return next_state('BLK-1', StateMachine.DEFAULT_NORMAL_SEVERITY, Status.Closed)
 
-            if previous_status != BLACKOUT:
+            if previous_status != Status.Blackout:
                 return next_state('BLK-2', current_severity, previous_status)
             else:
                 return next_state('BLK-*', current_severity, alert.status)
 
-        if state == CLOSED:
-            if action == ACTION_OPEN:
-                return next_state('CLS-1', previous_severity, OPEN)
-            if action == ACTION_ACK:
+        if state == Status.Closed:
+            if action == Action.OPEN:
+                return next_state('CLS-1', previous_severity, Status.Open)
+            if action == Action.ACK:
                 raise InvalidAction('invalid action for current {} status'.format(state))
-            if action == ACTION_SHELVE:
+            if action == Action.SHELVE:
                 raise InvalidAction('invalid action for current {} status'.format(state))
-            if action == ACTION_CLOSE:
+            if action == Action.CLOSE:
                 raise InvalidAction('alert is already in {} status'.format(state))
 
             if StateMachine.Severity[current_severity] != StateMachine.NORMAL_SEVERITY_LEVEL:
-                if previous_status == SHELVED:
-                    return next_state('CLS-2', previous_severity, SHELVED)
+                if previous_status == Status.Shelved:
+                    return next_state('CLS-2', previous_severity, Status.Shelved)
                 else:
-                    return next_state('CLS-3', previous_severity, OPEN)
+                    return next_state('CLS-3', previous_severity, Status.Open)
 
         # auto-close normal severity alerts from ANY state
         if StateMachine.Severity[current_severity] == StateMachine.NORMAL_SEVERITY_LEVEL:
-            return next_state('CLS-*', StateMachine.DEFAULT_NORMAL_SEVERITY, CLOSED)
+            return next_state('CLS-*', StateMachine.DEFAULT_NORMAL_SEVERITY, Status.Closed)
 
-        if state == EXPIRED:
-            if action and action != ACTION_OPEN:
+        if state == Status.Expired:
+            if action and action != Action.OPEN:
                 raise InvalidAction('invalid action for current {} status'.format(state))
             if StateMachine.Severity[current_severity] != StateMachine.NORMAL_SEVERITY_LEVEL:
-                return next_state('EXP-1', current_severity, OPEN)
+                return next_state('EXP-1', current_severity, Status.Open)
 
         return next_state('ALL-*', current_severity, current_status)
 
     @staticmethod
     def is_suppressed(alert):
-        return alert.status == BLACKOUT
+        return alert.status == Status.Blackout
