@@ -477,8 +477,8 @@ class Alert:
 
     # search alerts
     @staticmethod
-    def find_all(query: Query = None, page: int = 1, page_size: int = 1000) -> List['Alert']:
-        return [Alert.from_db(alert) for alert in db.get_alerts(query, page, page_size)]
+    def find_all(query: Query = None, raw_data: bool = False, history: bool = False, page: int = 1, page_size: int = 1000) -> List['Alert']:
+        return [Alert.from_db(alert) for alert in db.get_alerts(query, raw_data, history, page, page_size)]
 
     @staticmethod
     def get_alert_history(alert, page=1, page_size=100):
@@ -589,12 +589,12 @@ class Alert:
 
         status, _, previous_status, previous_timeout = self._get_hist_info(action)
 
-        if action in ['unack', 'unshelve', 'timeout']:
+        if action in [ChangeType.unack, ChangeType.unshelve, ChangeType.timeout]:
             timeout = timeout or previous_timeout
 
-        if action in ['ack', 'unack']:
+        if action in [ChangeType.ack, ChangeType.unack]:
             timeout = timeout or current_app.config['ACK_TIMEOUT']
-        elif action in ['shelve', 'unshelve']:
+        elif action in [ChangeType.shelve, ChangeType.unshelve]:
             timeout = timeout or current_app.config['SHELVE_TIMEOUT']
         else:
             timeout = timeout or self.timeout or current_app.config['ALERT_TIMEOUT']
