@@ -9,6 +9,7 @@ from alerta.models.enums import Scope
 from alerta.models.permission import Permission
 from alerta.models.user import User
 from alerta.utils.audit import admin_audit_trail, write_audit_trail
+from alerta.utils.paging import Page
 from alerta.utils.response import jsonp
 
 from . import api
@@ -130,18 +131,28 @@ def get_me_attributes():
 @jsonp
 def list_users():
     query = qb.from_params(request.args)
-    users = User.find_all(query)
+    total = User.count(query)
+    paging = Page.from_params(request.args, total)
+    users = User.find_all(query, page=paging.page, page_size=paging.page_size)
 
     if users:
         return jsonify(
             status='ok',
+            page=paging.page,
+            pageSize=paging.page_size,
+            pages=paging.pages,
+            more=paging.has_more,
             users=[user.serialize for user in users],
             domains=current_app.config['ALLOWED_EMAIL_DOMAINS'],
-            total=len(users)
+            total=total
         )
     else:
         return jsonify(
             status='ok',
+            page=paging.page,
+            pageSize=paging.page_size,
+            pages=paging.pages,
+            more=paging.has_more,
             message='not found',
             users=[],
             domains=current_app.config['ALLOWED_EMAIL_DOMAINS'],
@@ -174,13 +185,13 @@ def update_user(user_id):
                 raise ApiError("Requested scope '{}' not in existing scopes: {}".format(
                     want_scope, ','.join(g.scopes)), 403)
 
-    resp = user.update(**request.json)
+    updated = user.update(**request.json)
 
     admin_audit_trail.send(current_app._get_current_object(), event='user-updated', message='', user=g.login,
                            customers=g.customers, scopes=g.scopes, resource_id=user.id, type='user', request=request)
 
-    if resp:
-        return jsonify(status='ok')
+    if updated:
+        return jsonify(status='ok', user=updated.serialize)
     else:
         raise ApiError('failed to update user', 500)
 
@@ -208,13 +219,13 @@ def update_me():
         if user_by_email and user_by_email.id != user.id:
             raise ApiError('user with that email already exists', 409)
 
-    resp = user.update(**request.json)
+    updated = user.update(**request.json)
 
     write_audit_trail.send(current_app._get_current_object(), event='user-me-updated', message='', user=g.login,
                            customers=g.customers, scopes=g.scopes, resource_id=user.id, type='user', request=request)
 
-    if resp:
-        return jsonify(status='ok')
+    if updated:
+        return jsonify(status='ok', user=updated.serialize)
     else:
         raise ApiError('failed to update user', 500)
 
